@@ -118,24 +118,22 @@ class OBDPort:
              print self.get_result()
              wx.PostEvent(self._notify_window, DebugEvent([2,"ate0 response:" + self.get_result()]))
 
-             self.send_command("at sp 0")  
+             self.send_command("at sp 0") # Set automatic protocol search mode 
              time.sleep(0.3)
-             print self.get_result()
-             wx.PostEvent(self._notify_window, DebugEvent([2,"atsp0 response:" + self.get_result()]))
-
-             time.sleep(0.1)
+             answ=self.get_result()
+             print answ
+             wx.PostEvent(self._notify_window, DebugEvent([2,"atsp0 response:" + answ]))
 
              self.send_command("0100")
              time.sleep(0.3)
              ready = self.get_result()
-             print ready
-             time.sleep(1.2)
+             print "Result: "+ready
+             time.sleep(1.0)
              wx.PostEvent(self._notify_window, DebugEvent([2,"0100 response1:" + ready]))
 
 #UNABLE TO CONNECT
 #SEARCHING...            
 
-
              if ready=="SEARCHING...":
                 time.sleep(1.5)
                 ready = self.get_result()
