@@ -153,7 +153,7 @@ class MyApp(wx.App):
             #print self.SERTIMEOUT
             #print self.RECONNATTEMPTS
 
-            self.port     = obd_io.OBDPort(self.portName,self._notify_window,self.SERTIMEOUT,self.RECONNATTEMPTS)
+            self.port = obd_io.OBDPort(self.portName,self._notify_window,self.SERTIMEOUT,self.RECONNATTEMPTS)
 
             if self.port.State==0: #Cant open serial port
                 return None
@@ -489,15 +489,30 @@ class MyApp(wx.App):
           self.configfilepath="pyobd.ini"
         else:
           self.configfilepath=os.environ['HOME']+'/.pyobdrc'
-        if self.config.read(self.configfilepath)==[]:
+        #if self.config.read(self.configfilepath)==[]:
 
-          self.COMPORT="/dev/ttyACM0"
-          self.RECONNATTEMPTS=5
-          self.SERTIMEOUT=2
+        self.COMPORT="/dev/ttyACM0"
+        self.RECONNATTEMPTS=5
+        self.SERTIMEOUT=2
+
+        try:
+           BToff = os.popen('cat /home/opt/pyobd/pyobd.conf | awk \'/BToff/ {print $2}\'').read()
+        except:
+           pass
+
+        lungh = len(str(BToff).strip())
+
+        if lungh==0 or lungh==(4):
+           BToff=True
         else:
-          self.COMPORT=self.config.get("pyOBD","COMPORT")
-          self.RECONNATTEMPTS=self.config.getint("pyOBD","RECONNATTEMPTS")
-          self.SERTIMEOUT=self.config.getint("pyOBD","SERTIMEOUT")
+           BToff=False
+
+        self.BToff=BToff
+
+        #else:
+        #  self.COMPORT=self.config.get("pyOBD","COMPORT")
+        #  self.RECONNATTEMPTS=self.config.getint("pyOBD","RECONNATTEMPTS")
+        #  self.SERTIMEOUT=self.config.getint("pyOBD","SERTIMEOUT")
         
         frame = wx.Frame(None, -1, "pyOBD-II for n900")
         self.frame=frame
@@ -603,24 +618,26 @@ class MyApp(wx.App):
 
         return True
 
+
     def OnVisitMaemo(self,event):
         stringa = 'dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"http://talk.maemo.org/showthread.php?t=81129"'
         os.popen(stringa)
 
+
     def OnHelpVisit(self,event):
         #webbrowser.open("http://www.obdtester.com/pyobd")
         stringa = 'dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"http://www.obdtester.com/pyobd"'
         os.popen(stringa)
 
+
     def OnHelpOrder(self,event):
         #webbrowser.open("http://www.obdtester.com/order")
         stringa = 'dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"http://www.obdtester.com/order"'
         os.popen(stringa)
 
 
-
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-14beta
+        Text = """pyobd-0.9.2-15beta
 Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
@@ -700,7 +717,7 @@ later version.
 
 
     def OnDisconnect(self,event): #disconnect connection to ECU
-        global btaddr
+        global btaddr, seriale, node, manager, bus, adapter, target_address , service, path
         print "stop"
 
         #w = sensorProduce()
@@ -714,7 +731,10 @@ later version.
         bus = dbus.SystemBus()
         manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
         adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
-        adapter.SetProperty('Powered',False)
+
+        #adapter.SetProperty('Powered',False)
+        node = seriale.Disconnect(service)
+
         time.sleep(0.1)
         self.settingmenu.Enable(ID_RESET,False)
 
@@ -800,7 +820,8 @@ later version.
         
     
     def scanSerial(self):
-        
+        global btaddr, seriale, node, manager, bus, adapter, target_address , service, path
+
 #rfcomm bluetooth
         global found, btname, btaddr
         target_address = None
@@ -965,6 +986,14 @@ later version.
         reconnectCtrl = wx.TextCtrl(reconnectPanel, -1, '',pos=(140,0), size=(35, 30))
         reconnectStatic = wx.StaticText(reconnectPanel,-1,'Reconnect attempts:',pos=(3,5),size=(140,30))
         reconnectCtrl.SetValue(str(self.RECONNATTEMPTS))
+
+        #automatic switch off of the BT
+        BT_Panel = wx.Panel(diag, -1)
+        BT_Static = wx.CheckBox(BT_Panel,-1,'BT OFF on EXIT',pos=(3,5),size=(250,30))
+        BT_Static.SetValue(self.BToff)
+
+
+
         
         #web open link button
 #m        self.OpenLinkButton = wx.Button(diag,-1,"Click here to order ELM-USB interface",size=(260,30))
@@ -985,6 +1014,9 @@ later version.
 
         sizer.Add(timeoutPanel,0)
         sizer.Add(reconnectPanel,0)
+
+        sizer.Add(BT_Panel,0)
+
         box  = wx.BoxSizer(wx.HORIZONTAL)
         box.Add(wx.Button(diag,wx.ID_OK),0)
         box.Add(wx.Button(diag,wx.ID_CANCEL),1)
@@ -995,11 +1027,19 @@ later version.
         sizer.Fit(diag)
         if found==1:
            r = diag.ShowModal()
+
            if r == wx.ID_OK:
               os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"OK, now select \'OBD-II\', then \'Connect to ECU\'"')
               self.settingmenu.Enable(ID_RESET,True)
               time.sleep(0.1)
+              self.BToff=BT_Static.GetValue()
 
+              if self.BToff==True:
+                log2='echo "BToff True" > /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
+              else:
+                log2='echo "BToff False" > /home/opt/pyobd/pyobd.conf'
+                os.popen(log2)
 
             
             #create section
@@ -1029,7 +1069,7 @@ later version.
         elif found==2:
             time.sleep(0.7)
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"BT dev. Found, but can\'t open serial port"')
-            time.sleep(0.8)
+            time.sleep(0.7)
             os.popen('dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:"BT dev. Found, but can\'t open serial port"')
 
         else:
@@ -1042,10 +1082,12 @@ later version.
         
     def OnExit(self,e = None):
         import sys
-        bus = dbus.SystemBus()
-        manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
-        adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
-        adapter.SetProperty('Powered',False)
+
+        if self.BToff==True:
+           bus = dbus.SystemBus()
+           manager = dbus.Interface(bus.get_object("org.bluez", "/"),"org.bluez.Manager")
+           adapter = dbus.Interface(bus.get_object("org.bluez", manager.DefaultAdapter()),"org.bluez.Adapter")
+           adapter.SetProperty('Powered',False)
 
         sys.exit(0)
 
